@@ -18,7 +18,12 @@ import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.bigquery.v2",
-    manifest={"StandardSqlDataType", "StandardSqlField", "StandardSqlStructType",},
+    manifest={
+        "StandardSqlDataType",
+        "StandardSqlField",
+        "StandardSqlStructType",
+        "StandardSqlTableType",
+    },
 )
 
 
@@ -54,9 +59,11 @@ class StandardSqlDataType(proto.Message):
         DATE = 10
         TIME = 20
         DATETIME = 21
+        INTERVAL = 26
         GEOGRAPHY = 22
         NUMERIC = 23
         BIGNUMERIC = 24
+        JSON = 25
         ARRAY = 16
         STRUCT = 17
 
@@ -97,4 +104,14 @@ class StandardSqlStructType(proto.Message):
     fields = proto.RepeatedField(proto.MESSAGE, number=1, message="StandardSqlField",)
 
 
+class StandardSqlTableType(proto.Message):
+    r"""A table type
+    Attributes:
+        columns (Sequence[google.cloud.bigquery_v2.types.StandardSqlField]):
+            The columns in this table type
+    """
+
+    columns = proto.RepeatedField(proto.MESSAGE, number=1, message="StandardSqlField",)
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
